django-widgy
============

django-widgy is a heterogeneous tree editor for Django that is
well-suited for use as a CMS. A heterogeneous tree is a tree where
each node can be a different type---just like HTML. Widgy provides
the representation for heterogeneous trees as well as an interactive
JavaScript editor for them. Widgy supports Django 1.4+.

Widgy was originally created for powerful content management, but it can
have many different uses.

.. toctree::
   :maxdepth: 2

   design/index
   contrib/index
   api/index
   tutorials/index
   changelog


Development
-----------

You can follow and contribute to Widgy's development on GitHub_.  There is a
developers mailing list available at `widgy@fusionbox.com
<https://groups.google.com/a/fusionbox.com/forum/#!forum/widgy>`_


.. image:: https://travis-ci.org/fusionbox/django-widgy.png?branch=master
   :target: http://travis-ci.org/fusionbox/django-widgy
   :alt: Build Status

.. _GitHub: https://github.com/fusionbox/django-widgy
